Module pruning

Structs

Relation

Functions

checked_pruning_expr
Build a pruning expr mask an existing bundle of stats Creates a stat based falsification expr using the stats in the scope_field_paths. These are of the form [[“col_0”, …, “col_n”, “stat_name”], …] for each stat.
field_path_stat_field_name
pruning_expr
Create a stat based falsification expr assuming all stats for all column in the expression exist

Type Aliases

RequiredStats