Function checked_pruning_expr

pub fn checked_pruning_expr(
    expr: &ExprRef,
    scope_field_paths: &ScopeFieldPathSet,
) -> Option<(ExprRef, RequiredStats)>
Build a pruning expr mask an existing bundle of stats Creates a stat based falsification expr using the stats in the scope_field_paths. These are of the form [[“col_0”, …, “col_n”, “stat_name”], …] for each stat.