pub struct PruningPredicate { /* private fields */ }Implementations
Sourceimpl PruningPredicate
impl PruningPredicate
pub fn try_new(original_expr: &ExprRef) -> Option<Self>
pub fn expr(&self) -> &ExprRef
pub fn required_stats(&self) -> &HashMap<FieldOrIdentity, HashSet<Stat>>
Sourcepub fn evaluate(&self, metadata: &dyn Array) -> VortexResult<Option<ArrayRef>>
pub fn evaluate(&self, metadata: &dyn Array) -> VortexResult<Option<ArrayRef>>
Evaluate this predicate against a per-chunk statistics table.
Returns Ok(None) if any of the required statistics are not present in metadata. If it returns Ok(Some(array)), the array is a boolean array with the same length as the metadata, and a true value means the chunk can be pruned.