ExprEncoding

Trait ExprEncoding 

pub trait ExprEncoding:
    'static
    + Send
    + Sync
    + Debug
    + Sealed {
    // Required methods
    fn as_any(&self) -> &dyn Any;
    fn id(&self) -> ExprId;
    fn build(
        &self,
        metadata: &[u8],
        children: Vec<ExprRef>,
    ) -> VortexResult<ExprRef>;
}
Encoding trait for a Vortex expression.

An ExprEncoding can be registered with a Vortex session in order to support deserialization via the expression protobuf representation.

Required Methods

fn as_any(&self) -> &dyn Any

fn id(&self) -> ExprId

Returns the ID of the expression encoding.

fn build( &self, metadata: &[u8], children: Vec<ExprRef>, ) -> VortexResult<ExprRef>

Deserializes an expression from its serialized form.

Returns None if the expression is not serializable.

Implementations

Source

impl dyn ExprEncoding + '_

pub fn is<V: VTable>(&self) -> bool

pub fn as_<V: VTable>(&self) -> &V::Encoding

pub fn as_opt<V: VTable>(&self) -> Option<&V::Encoding>