pub enum FoldDown<Out, Context> {
Abort(Out),
SkipChildren(Out),
Continue(Context),
}Variants
Abort(Out)
Abort the entire traversal and immediately return the result.
SkipChildren(Out)
Skip visiting children of the current node and return the result to the parent’s fold_up.
Continue(Context)
Continue visiting the fold_down of the children of the current node.