pub enum TraversalOrder {
Skip,
Stop,
Continue,
}Expand description
Define a data fusion inspired traversal pattern for visiting nodes in a Node,
for now only VortexExpr.
This traversal is a pre-order traversal.
There are control traversal controls TraversalOrder:
Skip: Skip visiting the children of the current node.Stop: Stop visiting any more nodes in the traversal.Continue: Continue with the traversal as expected.
Variants
Skip
In a top-down traversal, skip visiting the children of the current node. In the bottom-up phase of the traversal this does nothing (for now).
Stop
Stop visiting any more nodes in the traversal.
Continue
Continue with the traversal as expected.