Functions
- checked_
pruning_ expr - Build a pruning expr mask an existing bundle of stats
Create a stat based falsification expr using the stats in the
scope_field_paths. These are of the form [[“col_0”, …, “col_n”, “stat_name”], …] for each stat. - field_
path_ stat_ field_ name - pruning_
expr - Create a stat based falsification expr assuming all stats for all column in the expression exist