pub fn checked_pruning_expr(
expr: &ExprRef,
scope_field_paths: &ScopeFieldPathSet,
) -> Option<(ExprRef, RequiredStats)>Expand description
Build a pruning expr mask an existing bundle of stats
Create a stat based falsification expr using the stats in the scope_field_paths.
These are of the form
[[“col_0”, …, “col_n”, “stat_name”], …] for each stat.